==> apache-dubbo-3.1.9-src.zip: apache-dubbo-3.1.9-src/dubbo-compatible/src/main/java/com/alibaba/dubbo/common/serialize/Serialization.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.alibaba.dubbo.common.serialize;

import com.alibaba.dubbo.common.URL;

import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;

@Deprecated
public interface Serialization extends org.apache.dubbo.common.serialize.Serialization {

    ObjectOutput serialize(URL url, OutputStream output) throws IOException;

    ObjectInput deserialize(URL url, InputStream input) throws IOException;

    @Override
    default org.apache.dubbo.common.serialize.ObjectOutput serialize(org.apache.dubbo.common.URL url, OutputStream output) throws IOException {
        return this.serialize(new URL(url), output);
    }

    @Override
    default org.apache.dubbo.common.serialize.ObjectInput deserialize(org.apache.dubbo.common.URL url, InputStream input) throws IOException {
        return this.deserialize(new URL(url), input);
    }
}

==> apache-dubbo-3.2.19-src.zip: apache-dubbo-3.2.19-src/dubbo-compatible/src/main/java/com/alibaba/dubbo/common/serialize/Serialization.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.alibaba.dubbo.common.serialize;

import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;

import com.alibaba.dubbo.common.DelegateURL;
import com.alibaba.dubbo.common.URL;

@Deprecated
public interface Serialization extends org.apache.dubbo.common.serialize.Serialization {

    ObjectOutput serialize(URL url, OutputStream output) throws IOException;

    ObjectInput deserialize(URL url, InputStream input) throws IOException;

    @Override
    default org.apache.dubbo.common.serialize.ObjectOutput serialize(
            org.apache.dubbo.common.URL url, OutputStream output) throws IOException {
        return this.serialize(new DelegateURL(url), output);
    }

    @Override
    default org.apache.dubbo.common.serialize.ObjectInput deserialize(
            org.apache.dubbo.common.URL url, InputStream input) throws IOException {
        return this.deserialize(new DelegateURL(url), input);
    }
}
